@@ -2,13 +2,31 @@
 from .base_primitive import BasePrimitive
 from .bit_field import BitField
 from .byte import Byte
+from .bytes import Bytes
 from .delim import Delim
 from .dword import DWord
 from .from_file import FromFile
 from .group import Group
+from .mirror import Mirror
 from .qword import QWord
 from .random_data import RandomData
 from .static import Static
 from .string import String
 from .word import Word
-from .mirror import Mirror
+
+__all__ = [
+    "BasePrimitive",
+    "BitField",
+    "Byte",
+    "Bytes",
+    "Delim",
+    "DWord",
+    "FromFile",
+    "Group",
+    "Mirror",
+    "QWord",
+    "RandomData",
+    "Static",
+    "String",
+    "Word",
+]
