@@ -9,14 +9,14 @@ from past.builtins import xrange
 from ..helpers import crc16
 
 
-def dnp3(data, control_code="\x44", src="\x00\x00", dst="\x00\x00"):
+def dnp3(data, control_code=b"\x44", src=b"\x00\x00", dst=b"\x00\x00"):
     num_packets = int(math.ceil(float(len(data)) / 250.0))
     packets = []
 
     for i in xrange(num_packets):
         packet_slice = data[i * 250 : (i + 1) * 250]
 
-        p = "\x05\x64"
+        p = b"\x05\x64"
         p += six.int2byte(len(packet_slice))
         p += control_code
         p += dst
